<?php
/**
 * @file
 * Rules actions for Fool's Rules.
 */

/**
 * Implements hook_rules_action_info().
 */
function fools_rules_rules_action_info() {
  return array(
    'fools_rules_action_form_alter' => array(
      'label' => t('Alter Form'),
      'access' => 'administer fools rules',
      'parameter' => array(
        'form_id' => array(
          'label' => t('Form ID'),
          'type' => 'text',
          'description' => t('Name of the form. For example:
            <code>system_site_information_settings</code>.'),
          'restriction' => 'input',
        ),
        'property' => array(
          'label' => t('Property to modify'),
          'type' => 'text',
          'description' => t('Available values are Drupal form array key
            names, separated by a colon. For example: to modify
            <code>$form[\'site_information\'][\'#title\']</code>,
            use <code>site_information:#title</code>.'),
          'restriction' => 'input',
        ),
        'value' => array(
          'label' => t('Value to set'),
          'type' => 'text',
          'description' => t('Available values are any literal string, an
            integer, and true or false.'),
          'restriction' => 'input',
        ),
      ),
      'group' => t('Fool\'s Rules'),
      'help' => t('The Devel module\'s \'Display $page array\' setting can be
        helpful for finding the appropriate properties.'),
    ),
    'fools_rules_action_page_alter' => array(
      'label' => t('Alter Page'),
      'access' => 'administer fools rules',
      'parameter' => array(
        'property' => array(
          'label' => t('Property to modify'),
          'type' => 'text',
          'description' => t('Available values are Drupal render array key
            names, separated by a colon. For example: to modify
            <code>$page[\'footer\'][\'system_powered-by\'][\'#markup\']</code>,
            use <code>footer:system_powered-by:#markup</code>.'),
          'restriction' => 'input',
        ),
        'value' => array(
          'label' => t('Value to set'),
          'type' => 'text',
          'description' => t('Available values are any literal string, an
            integer, and true or false.'),
          'restriction' => 'input',
        ),
      ),
      'group' => t('Fool\'s Rules'),
      'help' => t('The Devel module\'s \'Display $page array\' setting can be
        helpful for finding the appropriate properties.'),
    ),
  );
}

/**
 * Action: form_alter.
 */
function fools_rules_action_form_alter($form_id, $property, $value) {
  $form_alter = &drupal_static('fools_rules_form_alter', array());

  $value = fools_rules_settype($value);

  // Populate $form_alter for hook_form_alter().
  $index['form_id'] = $form_id;
  $index['property'] = check_plain($property);
  $index['value'] = $value;
  $form_alter[] = $index;
}

/**
 * Action: page_alter.
 */
function fools_rules_action_page_alter($property, $value) {
  $page_alter = &drupal_static('fools_rules_page_alter', array());

  $value = fools_rules_settype($value);

  // Populate $page_alter for hook_page_alter().
  $index['property'] = check_plain($property);
  $index['value'] = $value;
  $page_alter[] = $index;
}
